==> laaws-soap-service-1.4.0-sources.jar: org/lockss/ws/reports/CounterReportsService.java <==
/*

Copyright (c) 2013-2019 Board of Trustees of Leland Stanford Jr. University,
all rights reserved.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
STANFORD UNIVERSITY BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

Except as contained in this notice, the name of Stanford University shall not
be used in advertising or otherwise to promote the sale, use or other dealings
in this Software without prior written authorization from Stanford University.

*/
package org.lockss.ws.reports;

import org.lockss.ws.entities.CounterReportParams;
import org.lockss.ws.entities.CounterReportResult;
import org.lockss.ws.entities.LockssWebServicesFault;

import javax.jws.WebMethod;
import javax.jws.WebParam;
import javax.jws.WebService;

/** The Counter Reports SOAP web service interface. */
@WebService
public interface CounterReportsService {

  /**
   * Provides a COUNTER report.
   *
   * @param reportParams A CounterReportParams with the parameters of the requested COUNTER report.
   * @return a CounterReportResult with the requested COUNTER report.
   * @throws LockssWebServicesFault if there are problems.
   */
  @WebMethod
  CounterReportResult getCounterReport(
      @WebParam(name = "reportParams") CounterReportParams reportParams)
      throws LockssWebServicesFault;
}

==> laaws-soap-service-1.5.1-sources.jar: org/lockss/ws/reports/CounterReportsService.java <==
/*

Copyright (c) 2013-2019 Board of Trustees of Leland Stanford Jr. University,
all rights reserved.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
STANFORD UNIVERSITY BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR
IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

Except as contained in this notice, the name of Stanford University shall not
be used in advertising or otherwise to promote the sale, use or other dealings
in this Software without prior written authorization from Stanford University.

*/
package org.lockss.ws.reports;

import org.lockss.ws.entities.CounterReportParams;
import org.lockss.ws.entities.CounterReportResult;
import org.lockss.ws.entities.LockssWebServicesFault;

import jakarta.jws.WebMethod;
import jakarta.jws.WebParam;
import jakarta.jws.WebService;

/** The Counter Reports SOAP web service interface. */
@WebService
public interface CounterReportsService {

  /**
   * Provides a COUNTER report.
   *
   * @param reportParams A CounterReportParams with the parameters of the requested COUNTER report.
   * @return a CounterReportResult with the requested COUNTER report.
   * @throws LockssWebServicesFault if there are problems.
   */
  @WebMethod
  CounterReportResult getCounterReport(
      @WebParam(name = "reportParams") CounterReportParams reportParams)
      throws LockssWebServicesFault;
}
